@@ -1,3 +1,6 @@
+import pywhatkit as kit
+
+
 class StringFunction:
     def __init__(self):
         self.text = None
@@ -34,8 +37,12 @@ class StringFunction:
         self.text = "".join(lst)
         return self.text
 
+    def writefile(self, filename):
+        with open(converttosf(filename).append(".txt"), "w+") as f:
+            f.write(self.text)
 
-def converttobs(strvar):
+
+def converttosf(strvar):
     x = StringFunction()
     x.text = strvar
     return x
@@ -45,3 +52,10 @@ def converttostr(stringfunctionvar: StringFunction):
     x = stringfunctionvar.text
     return x
 
+
+def libcredits():
+    print("This library was made by Leonard W. please look at the GitHub repostiory for informations about this library (https://www.github.com/thanamesleo/stringfunctions)")
+
+
+def toascii(file, output):
+    kit.image_to_ascii_art(file, output)
\ No newline at end of file
